﻿using System;
using System.Web.Mvc;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.MvcEdition;

namespace DisplayASimpleMap.Controllers
{
    public class DisplayASimpleMapController : Controller
    {
        public ActionResult DisplayASimpleMap()
        {
            Map map = new Map("Map1",
                 new System.Web.UI.WebControls.Unit(100, System.Web.UI.WebControls.UnitType.Percentage),
                 new System.Web.UI.WebControls.Unit(100, System.Web.UI.WebControls.UnitType.Percentage));

            map.MapUnit = GeographyUnit.DecimalDegree;
            map.CurrentExtent = new RectangleShape(-125, 72, 50, -46);

            map.MapTools.OverlaySwitcher.Enabled = true;


            map.MapBackground = new BackgroundLayer(new GeoSolidBrush(GeoColor.FromHtml("#E5E3DF")));
            map.CustomOverlays.Add(new WorldMapKitWmsWebOverlay("world") { IsVisibleInOverlaySwitcher = true });

            for (int i = 0; i < 10; i++)
            {
                LayerOverlay lo = new LayerOverlay("Disable Layer " + i);
                ShapeFileFeatureLayer shpLayer = new ShapeFileFeatureLayer(Server.MapPath("~/App_Data/Austinstreets.shp"));
                shpLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.StandardColors.Red, 3, false);
                shpLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                lo.IsVisible = false;
                lo.Layers.Add(shpLayer);
                map.CustomOverlays.Add(lo);

                if (i == 0)
                {
                    shpLayer.Open();
                    map.CurrentExtent = shpLayer.GetBoundingBox();
                }
            }

            for (int i = 0; i < 10; i++)
            {
                LayerOverlay lo = new LayerOverlay("visible Layer " + i);

                ShapeFileFeatureLayer shpLayer = new ShapeFileFeatureLayer(Server.MapPath("~/App_Data/Austinstreets.shp"));
                shpLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.StandardColors.Yellow, 1, false);
                shpLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                lo.IsVisible = true;

                lo.Layers.Add(shpLayer);
                map.CustomOverlays.Add(lo);

                if (i == 0)
                {
                    shpLayer.Open();
                    map.CurrentExtent = shpLayer.GetBoundingBox();
                }
            }

            return View(map);
        }


        [MapActionFilter]
        public void ChangeOverlayVisibility(Map map, GeoCollection<object> args)
        {
            LayerOverlay overlay = map.CustomOverlays[args[0].ToString()] as LayerOverlay;
            if (overlay != null)
            {
                bool visible = bool.Parse(args[1].ToString());
                overlay.IsVisible = visible;
            }
        }
    }
}